chiark / gitweb /
changelog: Finalise 2.2
[innduct.git] / help.c
diff --git a/help.c b/help.c
index 8a47c3f4c16e2d0bacc8206ada933ae91d3e7c3b..cd563c4092c936e6b6db5ba50faa99c7611def29 100644 (file)
--- a/help.c
+++ b/help.c
@@ -3,25 +3,9 @@
  *  tailing reliable realtime streaming feeder for inn
  *  help.c - logging and utility functions
  *
- *  Copyright (C) 2010 Ian Jackson <ijackson@chiark.greenend.org.uk>
- * 
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation, either version 3 of the License, or
- *  (at your option) any later version.
- * 
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- * 
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- *  (I believe that when you compile and link this as part of the inn2
- *  build, with the Makefile runes I have provided, all the libraries
- *  and files which end up included in innduct are licence-compatible
- *  with GPLv3.  If not then please let me know.  -Ian Jackson.)
+ *  Copyright Ian Jackson <ijackson@chiark.greenend.org.uk>
+ *  and contributors; see LICENCE.txt.
+ *  SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #include "innduct.h"
@@ -49,7 +33,7 @@ static void logcore(int sysloglevel, const char *fmt, ...) {
 
 void logv(int sysloglevel, const char *pfx, int errnoval,
          const char *fmt, va_list al) {
-  char msgbuf[1024]; /* NB do not call xvasprintf here or you'll recurse */
+  char msgbuf[1024]; /* NB do not call mvasprintf here or you'll recurse */
   vsnprintf(msgbuf,sizeof(msgbuf), fmt,al);
   msgbuf[sizeof(msgbuf)-1]= 0;
 
@@ -97,16 +81,16 @@ DEFLOG(dbg,           "debug",    LOG_DEBUG,   -1)
 
 /*========== utility functions etc. ==========*/
 
-char *xvasprintf(const char *fmt, va_list al) {
+char *mvasprintf(const char *fmt, va_list al) {
   char *str;
   int rc= vasprintf(&str,fmt,al);
   if (rc<0) sysdie("vasprintf(\"%s\",...) failed", fmt);
   return str;
 }
 
-char *xasprintf(const char *fmt, ...) {
+char *masprintf(const char *fmt, ...) {
   VA;
-  char *str= xvasprintf(fmt,al);
+  char *str= mvasprintf(fmt,al);
   va_end(al);
   return str;
 }